@@ -27,6 +27,10 @@ core_opts = [
     cfg.StrOpt('subnetpool_name_prefix',
                default='kuryrPool',
                help=_('Neutron subnetpool name will be prefixed by this.')),
+    cfg.StrOpt('deployment_type',
+               default='baremetal',
+               help=_("baremetal or nested-containers are the supported"
+                      " values.")),
 ]
 
 neutron_group = cfg.OptGroup(
@@ -62,10 +66,23 @@ neutron_opts = [
 binding_opts = [
     cfg.StrOpt('veth_dst_prefix',
                default='eth',
-               help=('The name prefix of the veth endpoint put inside the '
-                     'container.'))
+               help=_('The name prefix of the veth endpoint put inside the '
+                     'container.')),
+    cfg.StrOpt('driver',
+               default='kuryr.lib.binding.drivers.veth',
+               help=_('Driver to use for binding and unbinding ports.')),
+    cfg.StrOpt('link_iface',
+               default='',
+               help=_('Specifies the name of the Nova instance interface to '
+                      'link the virtual devices to (only applicable to some '
+                      'binding drivers.')),
 ]
 
+binding_group = cfg.OptGroup(
+    'binding',
+    title='binding options',
+    help=_('Configuration options for container interface binding.'))
+
 
 def register_neutron_opts(conf):
     conf.register_group(neutron_group)
